@@ -1,3 +1,4 @@
+import logging
 import pathlib
 import re
 from typing import Optional, Tuple, List
@@ -64,11 +65,11 @@ low_priority_urls: List[str] = [
 feed_link_types: List[str] = ["application/json", "rss", "atom", "rdf"]
 
 
+logger = logging.getLogger(__name__)
+
+
 class LinkFilter:
-    def __init__(
-        self, logger, response: Response, request: Request, full_crawl: bool = False
-    ):
-        self.logger = logger
+    def __init__(self, response: Response, request: Request, full_crawl: bool = False):
         self.response = response
         self.request = request
         self.full_crawl = full_crawl
@@ -83,7 +84,7 @@ class LinkFilter:
         href: str = link.get("href")
         link_type: str = link.get("type")
 
-        url: URL = parse_href_to_url(self.logger, href)
+        url: URL = parse_href_to_url(href)
         if not url:
             return None
 
@@ -110,6 +111,9 @@ class LinkFilter:
         if not self.full_crawl and not is_feedlike_url and not is_podcast_url:
             return
 
+        # This check is deprecated, as it has been moved to the spider to prevent the crawling of any links
+        # from responses that are not the same as the original domain
+        #
         # is_one_jump: bool = self.is_one_jump_from_original_domain(url, self.response)
         # if not is_one_jump:
         #     return
@@ -172,9 +176,10 @@ class LinkFilter:
         """
 
         # This is the first Response in the chain
-        if len(response.history) == 1:
+        if len(response.history) < 2:
             return True
 
+        # The URL is relative, so on the same domain
         if not url.is_absolute():
             return True
 
